@@ -149,6 +149,7 @@ main (int argc, char **argv)
 
   TEST_CONFORM_SIMPLE ("/actor/iter", actor_iter_traverse_children);
   TEST_CONFORM_SIMPLE ("/actor/iter", actor_iter_traverse_remove);
+  TEST_CONFORM_SIMPLE ("/actor/iter", actor_iter_assignment);
 
   TEST_CONFORM_SIMPLE ("/actor/invariants", actor_initial_state);
   TEST_CONFORM_SIMPLE ("/actor/invariants", actor_shown_not_parented);
@@ -161,6 +162,7 @@ main (int argc, char **argv)
   TEST_CONFORM_SIMPLE ("/actor/invariants", clone_no_map);
   TEST_CONFORM_SIMPLE ("/actor/invariants", actor_contains);
   TEST_CONFORM_SIMPLE ("/actor/invariants", default_stage);
+  TEST_CONFORM_SIMPLE ("/actor/invariants", actor_pivot_transformation);
 
   TEST_CONFORM_SIMPLE ("/actor/opacity", opacity_label);
   TEST_CONFORM_SIMPLE ("/actor/opacity", opacity_rectangle);
@@ -188,6 +190,9 @@ main (int argc, char **argv)
   TEST_CONFORM_SIMPLE ("/texture", texture_fbo);
   TEST_CONFORM_SIMPLE ("/texture/cairo", texture_cairo);
 
+  TEST_CONFORM_SIMPLE ("/interval", interval_initial_state);
+  TEST_CONFORM_SIMPLE ("/interval", interval_transform);
+
   TEST_CONFORM_SIMPLE ("/path", path_base);
 
   TEST_CONFORM_SIMPLE ("/binding-pool", binding_pool);
@@ -221,16 +226,21 @@ main (int argc, char **argv)
   TEST_CONFORM_SIMPLE ("/script", animator_properties);
   TEST_CONFORM_SIMPLE ("/script", animator_multi_properties);
   TEST_CONFORM_SIMPLE ("/script", state_base);
+  TEST_CONFORM_SIMPLE ("/script", script_margin);
 
   TEST_CONFORM_SIMPLE ("/timeline", timeline_base);
   TEST_CONFORM_SIMPLE ("/timeline", timeline_markers_from_script);
   TEST_CONFORM_SKIP (g_test_slow (), "/timeline", timeline_interpolation);
   TEST_CONFORM_SKIP (g_test_slow (), "/timeline", timeline_rewind);
+  TEST_CONFORM_SIMPLE ("/timeline", timeline_progress_mode);
+  TEST_CONFORM_SIMPLE ("/timeline", timeline_progress_step);
 
   TEST_CONFORM_SIMPLE ("/score", score_base);
 
   TEST_CONFORM_SIMPLE ("/behaviours", behaviours_base);
 
+  TEST_CONFORM_SIMPLE ("/events", events_touch);
+
   /* FIXME - see bug https://bugzilla.gnome.org/show_bug.cgi?id=655588 */
   TEST_CONFORM_TODO ("/cally", cally_text);
 
@@ -242,7 +252,7 @@ main (int argc, char **argv)
 
   TEST_CONFORM_SIMPLE ("/cogl/texture", test_cogl_npot_texture);
   TEST_CONFORM_SIMPLE ("/cogl/texture", test_cogl_multitexture);
-  TEST_CONFORM_SIMPLE ("/cogl/texture", test_cogl_texture_mipmaps);
+  TEST_CONFORM_TODO ("/cogl/texture", test_cogl_texture_mipmaps);
   TEST_CONFORM_SIMPLE ("/cogl/texture", test_cogl_texture_rectangle);
   TEST_CONFORM_SIMPLE ("/cogl/texture", test_cogl_texture_pixmap_x11);
   TEST_CONFORM_SIMPLE ("/cogl/texture", test_cogl_texture_get_set_data);
